EdgeRComplexDesign <- function(x,n,factors,the.file,fdr,LibraryLayout,Project,coe){

require(edgeR)

  coe = as.numeric(coe)

  fdr = as.numeric(fdr)

  g <- factor(factors)

  res9 <- DGEList(counts = x[,1:n], group=g)  # modify here the entries of the count columns

  print("You loaded this count file: ")
  print(head(res9$counts))

  colnames(res9) <- factor(c(1:n))

  res9 <- calcNormFactors(res9)

  print("Summary of the design: ")

  print(res9$samples)

  design=model.matrix( ~ LibraryLayout + g)

  print("Experimental design:")
  print(design)

  d2 = estimateGLMTrendedDisp(res9, design)
 
  d2 = estimateGLMTagwiseDisp(d2, design)

  f = glmFit(d2, design)

  #makeConstrast(B-A,levels=design)

  de = glmLRT(f, coef=coe)

  tt = topTags(de, n=nrow(res9))

  print("First five lines of the result table: ")
  print(head(tt$table))

  rn = rownames(tt$table)

 if(Sys.info()[[1]]=="Windows"){

  the.file2 = strsplit(the.file,"\\\\")
  the.file2 = the.file2[[1]][length(the.file2[[1]])]  #estract the namefile
  et9_results <- topTags( tt, n = nrow( tt$table ) , sort.by = "none" )$table # n = nrow( et9$table ) is used to print all results!
  a=paste(getwd(),"\\RNASeqGUI_Projects\\",Project,"\\Results",sep="")
  outputName=paste(the.file2,"_results_EdgeRComplexDesign.txt", sep="")
  b=paste(a,outputName,sep="\\")

  write.table( et9_results, file = b , quote=FALSE, sep="\t", row.names=TRUE)

  list_DE_EDGER = subset(et9_results, FDR<fdr) # select significant genes

  outputName=paste(the.file2,"_fdr=",fdr,"_DE_genes_EdgeRComplexDesign.txt", sep="")

  b=paste(a,outputName,sep="\\")

  write.table(list_DE_EDGER, file = b , quote=FALSE, sep="\t", row.names=TRUE)

  message=paste("Results of EdgeRComplexDesign have been saved in the ", Project,"\\Results folder!", sep="")
  print(message)

  outputName=paste(the.file2,"_MDS_EdgeRComplexDesign.pdf", sep="")

  a=paste(getwd(),"\\RNASeqGUI_Projects\\",Project,"\\Plots",sep="")

  b=paste(a,outputName,sep="\\")

  plotMDS(res9, labels=res9$samples$group,col=c("red","blue")[factor(g)])

  dev.print(device = pdf, file=b)

 #write into the project report
  report=paste("RNASeqGUI_Projects\\",Project,"\\Logs\\report.Rmd",sep="")

     message5 <- paste("  ",sep="\n")
     write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

     message2 <- paste(" * In the *EdgeR Interface*, you clicked the **Run EdgeRComplexDesign** button at `", Sys.time(),"` and the ",outputName," file has been saved in the `", Project,"\\Plots` folder.", sep="")
     write(message2, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "\n")

     message5 <- paste("  ",sep="\n")
     write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

     message2 <- paste("You chose the following count file: `",the.file,"`, fdr: `",fdr,"`, Project: `",Project,"`, ",sep="\n")
     write(message2, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "\n")

     message1 <- paste("factors= c(")
     write(message1, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message2 <- paste("'",factors[1:(length(factors)-1)],"',",sep="")
     write(message2, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message3 <- paste("'",factors[length(factors)],"'",sep="")
     write(message3, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message4 <- paste("), ")
     write(message4, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message1 <- paste("LibTypes= c(")
     write(message1, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message2 <- paste("'",LibraryLayout[1:(length(LibraryLayout)-1)],"',",sep="")
     write(message2, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message3 <- paste("'",LibraryLayout[length(LibraryLayout)],"'",sep="")
     write(message3, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message4 <- paste("). ")
     write(message4, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message5 <- paste("  ",sep="\n")
     write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

     message5 <- paste(" This R code has been run:",sep="\n")
     write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

     message5 <- paste("  ",sep="\n")
     write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste(" ```{r} ",sep="\n")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   x = read.table('",the.file,"',header=TRUE,row.names=1)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   x = data.matrix(x, rownames.force = NA)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   the.file ='",the.file,"'", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   n  ='",n,"'", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   Project ='", Project,"'", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

     message1 <- paste("factors= c(")
     write(message1, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message2 <- paste("'",factors[1:(length(factors)-1)],"',",sep="")
     write(message2, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message3 <- paste("'",factors[length(factors)],"'",sep="")
     write(message3, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message4 <- paste(")")
     write(message4, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message1 <- paste("LibraryLayout= c(")
     write(message1, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message2 <- paste("'",LibraryLayout[1:(length(LibraryLayout)-1)],"',",sep="")
     write(message2, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message3 <- paste("'",LibraryLayout[length(LibraryLayout)],"'",sep="")
     write(message3, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message4 <- paste(")")
     write(message4, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

message5 <- paste("   fdr ='",fdr,"'", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   coe ='",coe,"'", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  ",sep="\n")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   fdr = as.numeric(fdr)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   g <- factor(factors)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   coe = as.numeric(coe)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   res9 <- DGEList(counts = x[,1:n], group=g)  # modify here the entries of the count columns", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  print('You loaded this count file: ') ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  print(head(res9$counts)) ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   colnames(res9) <- factor(c(1:n))", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   res9 <- calcNormFactors(res9)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   design=model.matrix( ~ LibraryLayout + g)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   d2 = estimateGLMTrendedDisp(res9, design)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")
 
message5 <- paste("   d2 = estimateGLMTagwiseDisp(d2, design)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   f = glmFit(d2, design)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   de = glmLRT(f, coef=coe)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   tt = topTags(de, n=nrow(res9))", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  print('First five lines of the result table: ')", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  print(head(tt$table))", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   rn = rownames(tt$table)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   the.file2 = strsplit(the.file,'\\')", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   the.file2 = the.file2[[1]][length(the.file2[[1]])]  #estract the namefile", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   a=paste(getwd(),'\\RNASeqGUI_Projects\\',Project,'\\Plots\\',sep='')", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  outputName=paste(the.file2,'_results_EdgeRComplexDesign.txt', sep='')", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  b=paste(a,outputName,sep='\\') ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  et9_results <- topTags( tt, n = nrow( tt$table ) , sort.by = 'none' )$table # n = nrow( et9$table ) is used to print all results!", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("#  write.table( et9_results, file = b , quote=FALSE, sep='\t', row.names=TRUE) ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  list_DE_EDGER = subset(et9_results, FDR<fdr) # select significant genes ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  outputName=paste(the.file2,'_fdr=',fdr,'_DE_genes_EdgeRComplexDesign.txt', sep='') ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  b=paste(a,outputName,sep='\\') ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("#  write.table(list_DE_EDGER, file = b , quote=FALSE, sep='\t', row.names=TRUE) ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  outputName=paste(the.file2,'_MDS_EdgeRComplexDesign.pdf', sep='') ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  a=paste(getwd(),'\\RNASeqGUI_Projects\\',Project,'\\Plots',sep='') ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  b=paste(a,outputName,sep='\\') ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  plotMDS(res9, labels=res9$samples$group,col=c('red','blue')[factor(g)]) ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("#  dev.print(device = pdf, file=b) ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message8 <- paste(" ``` ",sep="\n")
write(message8, file = report,ncolumns = if(is.character(message8)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste(" _______________________________________________________________________ ",sep="\n")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

  #dev.off()

  #outputName=paste(the.file,"_Smear_EdgeR.pdf", sep="")

  #b=paste(a,outputName,sep="\\")

  #deg = rn[tt$table$FDR < .05]

  #plotSmear(res9, de.tags=deg) 

  #dev.print(device = pdf, file=b)

  print("FINISHED !")

  et9_results

 }else{ #Linux

  the.file2 = strsplit(the.file,"/")
  the.file2 = the.file2[[1]][length(the.file2[[1]])]  #estract the namefile
  et9_results <- topTags( tt, n = nrow( tt$table ) , sort.by = "none" )$table # n = nrow( et9$table ) is used to print all results!
  a=paste(getwd(),"/RNASeqGUI_Projects/",Project,"/Results",sep="")
  outputName=paste(the.file2,"_results_EdgeRComplexDesign.txt", sep="")
  b=paste(a,outputName,sep="/")

  et9_results <- topTags( tt, n = nrow( tt$table ) , sort.by = "none" )$table # n = nrow( et9$table ) is used to print all results!

  write.table( et9_results, file = b , quote=FALSE, sep="\t", row.names=TRUE)

  list_DE_EDGER = subset(et9_results, FDR<fdr) # select significant genes

  #de <- decideTestsDGE(et9) #genes significantly up-regulated or down-regulated at 5% FDR

  #isDE <- as.logical(de)

  #DEnames <- rownames(res9)[isDE]

  outputName=paste(the.file2,"_fdr=",fdr,"_DE_genes_EdgeRComplexDesign.txt", sep="")

  b=paste(a,outputName,sep="/")

  write.table(list_DE_EDGER, file = b , quote=FALSE, sep="\t", row.names=TRUE)

  message=paste("Results of 'EdgeRComplexDesign' have been saved in the ", Project,"/Results folder!", sep="")
  print(message)

  outputName=paste(the.file2,"_MDS_EdgeRComplexDesign.pdf", sep="")

  a=paste(getwd(),"/RNASeqGUI_Projects/",Project,"/Plots",sep="")

  b=paste(a,outputName,sep="/")

  plotMDS(res9, labels=res9$samples$group,col=c("red","blue")[factor(g)])

  dev.print(device = pdf, file=b)

 #write into the project report
  report=paste("RNASeqGUI_Projects/",Project,"/Logs/report.Rmd",sep="")

     message5 <- paste("  ",sep="\n")
     write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

     message2 <- paste(" * In the *EdgeR Interface*, you clicked the **Run EdgeRComplexDesign** button at `", Sys.time(),"` and the ",outputName," file has been saved in the `", Project,"/Plots` folder.", sep="")
     write(message2, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "\n")

     message5 <- paste("  ",sep="\n")
     write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

     message2 <- paste("You chose the following count file: `",the.file,"`, fdr: `",fdr,"`, Project: `",Project,"`, ",sep="\n")
     write(message2, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "\n")

     message1 <- paste("factors= c(")
     write(message1, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message2 <- paste("'",factors[1:(length(factors)-1)],"',",sep="")
     write(message2, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message3 <- paste("'",factors[length(factors)],"'",sep="")
     write(message3, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message4 <- paste("), ")
     write(message4, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message1 <- paste("LibTypes= c(")
     write(message1, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message2 <- paste("'",LibraryLayout[1:(length(LibraryLayout)-1)],"',",sep="")
     write(message2, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message3 <- paste("'",LibraryLayout[length(LibraryLayout)],"'",sep="")
     write(message3, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message4 <- paste("). ")
     write(message4, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message5 <- paste("  ",sep="\n")
     write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

     message5 <- paste(" This R code has been run:",sep="\n")
     write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

     message5 <- paste("  ",sep="\n")
     write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste(" ```{r} ",sep="\n")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   x = read.table('",the.file,"',header=TRUE,row.names=1)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   x = data.matrix(x, rownames.force = NA)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   the.file ='",the.file,"'", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   n  ='",n,"'", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   Project ='", Project,"'", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

     message1 <- paste("factors= c(")
     write(message1, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message2 <- paste("'",factors[1:(length(factors)-1)],"',",sep="")
     write(message2, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message3 <- paste("'",factors[length(factors)],"'",sep="")
     write(message3, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message4 <- paste(")")
     write(message4, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message1 <- paste("LibraryLayout= c(")
     write(message1, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message2 <- paste("'",LibraryLayout[1:(length(LibraryLayout)-1)],"',",sep="")
     write(message2, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message3 <- paste("'",LibraryLayout[length(LibraryLayout)],"'",sep="")
     write(message3, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

     message4 <- paste(")")
     write(message4, file = report,ncolumns = if(is.character(message2)) 1 else 5,append = TRUE, sep = "")

message5 <- paste("   fdr ='",fdr,"'", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   coe ='",coe,"'", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  ",sep="\n")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   fdr = as.numeric(fdr)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   g <- factor(factors)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   coe = as.numeric(coe)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   res9 <- DGEList(counts = x[,1:n], group=g)  # modify here the entries of the count columns", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  print('You loaded this count file: ') ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  print(head(res9$counts)) ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   colnames(res9) <- factor(c(1:n))", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   res9 <- calcNormFactors(res9)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   design=model.matrix( ~ LibraryLayout + g)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   d2 = estimateGLMTrendedDisp(res9, design)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")
 
message5 <- paste("   d2 = estimateGLMTagwiseDisp(d2, design)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   f = glmFit(d2, design)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   de = glmLRT(f, coef=coe)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   tt = topTags(de, n=nrow(res9))", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  print('First five lines of the result table: ')", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  print(head(tt$table))", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   rn = rownames(tt$table)", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   the.file2 = strsplit(the.file,'/')", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   the.file2 = the.file2[[1]][length(the.file2[[1]])]  #estract the namefile", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("   a=paste(getwd(),'/RNASeqGUI_Projects/',Project,'/Plots/',sep='')", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  outputName=paste(the.file2,'_results_EdgeRComplexDesign.txt', sep='')", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  b=paste(a,outputName,sep='/') ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  et9_results <- topTags( tt, n = nrow( tt$table ) , sort.by = 'none' )$table # n = nrow( et9$table ) is used to print all results!", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("#  write.table( et9_results, file = b , quote=FALSE, sep='\t', row.names=TRUE) ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  list_DE_EDGER = subset(et9_results, FDR<fdr) # select significant genes ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  outputName=paste(the.file2,'_fdr=',fdr,'_DE_genes_EdgeRComplexDesign.txt', sep='') ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  b=paste(a,outputName,sep='/') ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("#  write.table(list_DE_EDGER, file = b , quote=FALSE, sep='\t', row.names=TRUE) ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  outputName=paste(the.file2,'_MDS_EdgeRComplexDesign.pdf', sep='') ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  a=paste(getwd(),'/RNASeqGUI_Projects/',Project,'/Plots',sep='') ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  b=paste(a,outputName,sep='/') ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("  plotMDS(res9, labels=res9$samples$group,col=c('red','blue')[factor(g)]) ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste("#  dev.print(device = pdf, file=b) ", sep="")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

message8 <- paste(" ``` ",sep="\n")
write(message8, file = report,ncolumns = if(is.character(message8)) 1 else 5,append = TRUE, sep = "\n")

message5 <- paste(" _______________________________________________________________________ ",sep="\n")
write(message5, file = report,ncolumns = if(is.character(message5)) 1 else 5,append = TRUE, sep = "\n")

  #dev.off()

  #outputName=paste(the.file,"_Smear_EdgeR.pdf", sep="")

  #b=paste(a,outputName,sep="/")

  #deg = rn[tt$table$FDR < .05]

  #plotSmear(res9, de.tags=deg) 

  #dev.print(device = pdf, file=b)

  print("FINISHED !")

  et9_results

 }

}
